#
# spec file for package libfixbuf
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 9
Name:           libfixbuf
Version:        2.4.2
Release:        2.1
Summary:        Implementation of the IPFIX Protocol as a C library
License:        LGPL-3.0-only
Group:          System/Libraries
URL:            https://tools.netsa.cert.org/fixbuf
Source:         https://tools.netsa.cert.org/releases/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  glib2-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libfixbuf is a compliant implementation of the IPFIX Protocol, as defined in
RFC 5101. It supports the information model defined in RFC 5102, extended as
proposed by RFC 5103 to support information elements for representing biflows.
libfixbuf supports UDP, TCP, SCTP, TLS over TCP, and Spread as transport
protocols. It also supports operation as an IPFIX File Writer or IPFIX File
Reader.

ipfixDump is a command line tool for printing the contents of an IPFIX
file as text.

%package -n libfixbuf%{sover}
Summary:        Development files for the libfixbuf library
Group:          System/Libraries

%description -n libfixbuf%{sover}
libfixbuf is a compliant implementation of the IPFIX Protocol, as defined in
RFC 5101. It supports the information model defined in RFC 5102, extended as
proposed by RFC 5103 to support information elements for representing biflows.
libfixbuf supports UDP, TCP, SCTP, TLS over TCP, and Spread as transport
protocols.

%package devel
Summary:        Development files for the libfixbuf library
Group:          Development/Libraries/C and C++
Requires:       libfixbuf%{sover} = %{version}

%description devel
libfixbuf aims to be a compliant implementation of the IPFIX Protocol
and message format, from which IPFIX Collecting Processes and
IPFIX Exporting Processes may be built.

This subpackage contains libraries and header files for developing
applications that want to make use of libfixbuf.

%package tools
Summary:        IPFIX file dumper
Group:          Productivity/Networking/Diagnostic

%description tools
libfixbuf is a compliant implementation of the IPFIX Protocol, as defined in
RFC 5101. It supports the information model defined in RFC 5102, extended as
proposed by RFC 5103 to support information elements for representing biflows.
libfixbuf supports UDP, TCP, SCTP, TLS over TCP, and Spread as transport
protocols.

ipfixDump is a command line tool for printing the contents of an IPFIX
file as text.

%prep
%setup -q

%build
autoreconf -fiv
%configure
%make_build

%install
%make_install
rm %{buildroot}/%{_libdir}/*.{la,a}

%post   -n libfixbuf%{sover} -p /sbin/ldconfig
%postun -n libfixbuf%{sover} -p /sbin/ldconfig

%files -n libfixbuf%{sover}
%license LICENSE.txt
%doc AUTHORS NEWS README
%{_libdir}/libfixbuf.so.%{sover}*

%files devel
%license LICENSE.txt
%dir %{_includedir}/fixbuf
%{_includedir}/fixbuf/*.h
%{_libdir}/libfixbuf.so
%{_libdir}/pkgconfig/libfixbuf.pc

%files tools
%license LICENSE.txt
%{_bindir}/ipfixDump
%{_datadir}/libfixbuf
%{_datadir}/libfixbuf/cert_ipfix.xml
%{_mandir}/man1/ipfixDump.1%{?ext_man}

%changelog
* Fri Mar 21 2025 Andreas Stieger <andreas.stieger@gmx.de>
- remove unused pcre build dependency
* Tue May  2 2023 Dirk Müller <dmueller@suse.com>
- update to version 2.4.2:
  * Updated CERT IPFIX elements to include those added in
    libfixbuf 3.0.  This update does not include the element name
    changes that were part of that release.
* Wed Jan  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.1
  * Added support for OpenSSL 1.1.0 and removed support for
    versions prior to 1.0.2.
  * Updated CERT IPFIX elements.
* Sun Nov 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.0
  * Enhanced the output of ipfixDump by (1) including the
    template's name with its list of elements, (2) adding the
    templates' names to the stats output, (3) marking scope
    elements in templates and their corresponding values in data
    records, and (4) including the name for list semantics.
  * Changed how the information model handles the re-insertion an
    existing element to reuse the existing element instead of
    using new memory.
  * Added stricter checking of the elements lengths' specified in
    a template. Currently a log message is written for an invalid
    length; in the future, this may cause the template to be
    rejected.
* Thu Apr 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.1
  * Fixed a double-freeing of memory and memory leaks in some of
    the error handling code.
* Wed Mar 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.0
  * Added the ipfixDump application which used to be included with
    YAF, and made many changes to the application.
    Use configure --disable-tools to prevent building and installing
    ipfixDump.
  * Fixed bugs in reading and writing information elements whose
    type was list and elementId was a value other than 291, 292, or 293.
  * information element type information and exporting template
    metadata.
- Update to version 2.2.0
  * Added functions to return the buffer size required to read a
    template and the maximum buffer size to process all known
    templates in a session.
  * Modified library to return an error when a user attempts to use
    a reserved template ID.
  * Fixed a potential use-after-free bug triggered by pyfixbuf.
* Sat Jul 14 2018 mardnh@gmx.de
- Update to version 2.1.0
  * Add functions to update the Information Model with Information
    Elements read from a file or a string containing XML data
  * Set an element's endian flag when incorporating elements from
    options records
  * GLib 2.18 or later is now required
* Thu May  3 2018 mardnh@gmx.de
- Update to version 2.0.0
  * This version is not backwards-compatible with fixbuf 1.x.
  * Change source for infomodel to the IANA XML version of the
    IPFIX Information Elements.
  * Require information element specifications for internal records to
    have non-defaulted (non-zero) sizes.
  * Simplify new template callbacks, subsuming the three variants with
    one: fbSessionAddNewTemplateCallback().
  * The default is now to consider the source port when separating
    incoming UDP streams.  The function fbCollectorManageUDPStreamByPort()
    has been removed.
  * Change fbInfoElementWriteOptionsRecord() to take both the internal and
    external template id.
  * Update to LGPL 3.
- Update to version 1.8.0
  * The ability to add template metadata to exported templates
  * Macro to check fixbuf version number
  * Minor bug fixes
* Sun Oct 22 2017 mardnh@gmx.de
- Update to version 1.7.1:
  + Bug Fix for NetFlow v9 devices that implement
    Reverse Information Elements
* Sat Jul  4 2015 mardnh@gmx.de
- Version 1.7.0: 2015-07-01
  + Update IPFIX Information Elements to be compatible with IANA registry
  + Add recursive freeing function fBufListFree() to free structured data
    elements
  + Ignore extra filling bytes in sFlow records
  + Bug Fix for NetFlow v9 Options Template Parsing
  + Other Bug Fixes
* Sun Dec 28 2014 mardnh@gmx.de
- Version 1.6.2: 2014-12-03
  + Bug Fix for NetFlow v9 collectors with multiple streams
  + Other Bug Fixes
- Version 1.6.1: 2014-10-14
  + Bug Fix for UDP connections that timeout frequently
- Version 1.6.0: 2014-09-29
  + New Support for sFlow
  + Added support for decoding basicLists with unknown information elements
  + New Template Callback Function
  + Updated IPFIX Information Elements to be compatible with IANA registry
- Version 1.5.0: 2014-06-18
  + Updated IPFIX Information Elements to be compatible with IANA registry
  + Added the ability to decode IPFIX from application's own data buffer
  + Replaced select() with poll() for fbListeners.
    Applications will now bind to all addresses returned by getaddrinfo
  + Added an InfoModel Iterator
  + Removed fbListenerGroupWaitAcceptCallback() API function
  + Removed fbListenerWaitAcceptCallback() API function
  + Renamed IPFIX Structured Data Type Semantic #defines
  + Bug Fix for NetFlow v9 Options Templates
  + Other Bug Fixes
- Version 1.4.0: 2013-12-02
  + pyfixbuf, a python API for libfixbuf, is included as a separate package
    within the tarball (optional install)
  + UDP IPFIX Listeners now reject IPFIX messages with invalid version numbers
  + Added Environment Variable, FB_SUPPRESS_LOGS, to suppress NetFlow v9
    log messages
  + NetFlow v9 Options Templates and Records are now collected and translated
    to IPFIX.
  + An fbInfoElement_st now contains all of the properties listed in RFC 5610.
  + Added a macro, FB_IE_INIT_FULL, to define an Information Element with
    additional properties
  + New API functions to create Options Templates/Records for encoding
    Information Element type information.
  + New API functions to collect Information Element type records.
  + New Template Callback for application to provide context to an incoming
    Template.
  + IPFIX Elements updated to be compatible with IANA registry.
  + NetFlow v9 compatible elements added to default Information Model.
* Sat Sep  7 2013 mardnh@gmx.de
- initial package written from scratch
